'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const isSigner = value => {
  return 'publicKey' in value;
};
const createSignerFromKeypair = (context, keypair) => {
  return {
    publicKey: keypair.publicKey,
    async signMessage(message) {
      return context.eddsa.sign(message, keypair);
    },
    async signTransaction(transaction) {
      transaction.sign([keypair]);
      return transaction;
    },
    async signAllTransactions(transactions) {
      return Promise.all(transactions.map(transaction => this.signTransaction(transaction)));
    }
  };
};
const createNoopSigner = publicKey => {
  return {
    publicKey,
    async signMessage(message) {
      return message;
    },
    async signTransaction(transaction) {
      return transaction;
    },
    async signAllTransactions(transactions) {
      return transactions;
    }
  };
};
const createNullSigner = () => {
  return new NullSigner();
};
class NullSigner {
  // TODO(loris): Custom errors.
  get publicKey() {
    throw new Error('Method not implemented.');
  }
  signMessage() {
    throw new Error('Method not implemented.');
  }
  signTransaction() {
    throw new Error('Method not implemented.');
  }
  signAllTransactions() {
    throw new Error('Method not implemented.');
  }
}

exports.NullSigner = NullSigner;
exports.createNoopSigner = createNoopSigner;
exports.createNullSigner = createNullSigner;
exports.createSignerFromKeypair = createSignerFromKeypair;
exports.isSigner = isSigner;
//# sourceMappingURL=Signer.cjs.map
